==> tencentcloud_sdk_python-3.0.25-py2.py3-none-any.whl: tencentcloud/aai/v20180522/models.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from tencentcloud.common.abstract_model import AbstractModel


class ChatRequest(AbstractModel):
    """Chat请求参数结构体

    """

    def __init__(self):
        """
        :param Text: 聊天输入文本
        :type Text: str
        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
        :type ProjectId: int
        :param User: json格式，比如 {"id":"test","gender":"male"}。记录当前与机器人交互的用户id，非必须但强烈建议传入，否则多轮聊天功能会受影响
        :type User: str
        """
        self.Text = None
        self.ProjectId = None
        self.User = None


    def _deserialize(self, params):
        self.Text = params.get("Text")
        self.ProjectId = params.get("ProjectId")
        self.User = params.get("User")


class ChatResponse(AbstractModel):
    """Chat返回参数结构体

    """

    def __init__(self):
        """
        :param Answer: 聊天输出文本
        :type Answer: str
        :param RequestId: 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
        :type RequestId: str
        """
        self.Answer = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Answer = params.get("Answer")
        self.RequestId = params.get("RequestId")


class SentenceRecognitionRequest(AbstractModel):
    """SentenceRecognition请求参数结构体

    """

    def __init__(self):
        """
        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
        :type ProjectId: int
        :param SubServiceType: 子服务类型。2，一句话识别。
        :type SubServiceType: int
        :param EngSerViceType: 引擎类型。8k：电话 8k 通用模型；16k：16k 通用模型。只支持单声道音频识别。
        :type EngSerViceType: str
        :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
        :type SourceType: int
        :param VoiceFormat: 识别音频的音频格式（支持mp3,wav）。
        :type VoiceFormat: str
        :param UsrAudioKey: 用户端对此任务的唯一标识，用户自助生成，用于用户查找识别结果。
        :type UsrAudioKey: str
        :param Url: 语音 URL，公网可下载。当 SourceType 值为 0 时须填写该字段，为 1 时不填；URL 的长度大于 0，小于 2048，需进行urlencode编码。音频时间长度要小于60s。
        :type Url: str
        :param Data: 语音数据，当SourceType 值为1时必须填写，为0可不写。要base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。音频数据要小于900k。
        :type Data: str
        :param DataLen: 数据长度，当 SourceType 值为1时必须填写，为0可不写（此数据长度为数据未进行base64编码时的数据长度）。
        :type DataLen: int
        """
        self.ProjectId = None
        self.SubServiceType = None
        self.EngSerViceType = None
        self.SourceType = None
        self.VoiceFormat = None
        self.UsrAudioKey = None
        self.Url = None
        self.Data = None
        self.DataLen = None


    def _deserialize(self, params):
        self.ProjectId = params.get("ProjectId")
        self.SubServiceType = params.get("SubServiceType")
        self.EngSerViceType = params.get("EngSerViceType")
        self.SourceType = params.get("SourceType")
        self.VoiceFormat = params.get("VoiceFormat")
        self.UsrAudioKey = params.get("UsrAudioKey")
        self.Url = params.get("Url")
        self.Data = params.get("Data")
        self.DataLen = params.get("DataLen")


class SentenceRecognitionResponse(AbstractModel):
    """SentenceRecognition返回参数结构体

    """

    def __init__(self):
        """
        :param Result: 识别结果。
        :type Result: str
        :param RequestId: 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
        :type RequestId: str
        """
        self.Result = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Result = params.get("Result")
        self.RequestId = params.get("RequestId")


class SimultaneousInterpretingRequest(AbstractModel):
    """SimultaneousInterpreting请求参数结构体

    """

    def __init__(self):
        """
        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
        :type ProjectId: int
        :param SubServiceType: 子服务类型。0：离线语音识别。1：实时流式识别，2，一句话识别。3：同传。
        :type SubServiceType: int
        :param RecEngineModelType: 识别引擎类型。8k_zh： 8k 中文会场模型；16k_zh：16k 中文会场模型，8k_en： 8k 英文会场模型；16k_en：16k 英文会场模型。当前仅支持16K。
        :type RecEngineModelType: str
        :param Data: 语音数据，要base64编码。
        :type Data: str
        :param DataLen: 数据长度。
        :type DataLen: int
        :param VoiceId: 声音id，标识一句话。
        :type VoiceId: str
        :param IsEnd: 是否是一句话的结束。
        :type IsEnd: int
        :param VoiceFormat: 声音编码的格式1:pcm，4:speex，6:silk，默认为1。
        :type VoiceFormat: int
        :param OpenTranslate: 是否需要翻译结果，1表示需要翻译，0是不需要。
        :type OpenTranslate: int
        :param SourceLanguage: 如果需要翻译，表示源语言类型，可取值：zh，en。
        :type SourceLanguage: str
        :param TargetLanguage: 如果需要翻译，表示目标语言类型，可取值：zh，en。
        :type TargetLanguage: str
        :param Seq: 表明当前语音分片的索引，从0开始
        :type Seq: int
        """
        self.ProjectId = None
        self.SubServiceType = None
        self.RecEngineModelType = None
        self.Data = None
        self.DataLen = None
        self.VoiceId = None
        self.IsEnd = None
        self.VoiceFormat = None
        self.OpenTranslate = None
        self.SourceLanguage = None
        self.TargetLanguage = None
        self.Seq = None


    def _deserialize(self, params):
        self.ProjectId = params.get("ProjectId")
        self.SubServiceType = params.get("SubServiceType")
        self.RecEngineModelType = params.get("RecEngineModelType")
        self.Data = params.get("Data")
        self.DataLen = params.get("DataLen")
        self.VoiceId = params.get("VoiceId")
        self.IsEnd = params.get("IsEnd")
        self.VoiceFormat = params.get("VoiceFormat")
        self.OpenTranslate = params.get("OpenTranslate")
        self.SourceLanguage = params.get("SourceLanguage")
        self.TargetLanguage = params.get("TargetLanguage")
        self.Seq = params.get("Seq")


class SimultaneousInterpretingResponse(AbstractModel):
    """SimultaneousInterpreting返回参数结构体

    """

    def __init__(self):
        """
        :param AsrText: 语音识别的结果
        :type AsrText: str
        :param NmtText: 机器翻译的结果
        :type NmtText: str
        :param RequestId: 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
        :type RequestId: str
        """
        self.AsrText = None
        self.NmtText = None
        self.RequestId = None


    def _deserialize(self, params):
        self.AsrText = params.get("AsrText")
        self.NmtText = params.get("NmtText")
        self.RequestId = params.get("RequestId")


class TextToVoiceRequest(AbstractModel):
    """TextToVoice请求参数结构体

    """

    def __init__(self):
        """
        :param Text: 合成语音的源文本
        :type Text: str
        :param SessionId: 一次请求对应一个SessionId，会原样返回，建议传入类似于uuid的字符串防止重复
        :type SessionId: str
        :param ModelType: 模型类型，1-默认模型
        :type ModelType: int
        :param Volume: 音量大小，范围：[0，10]，分别对应10个等级的音量，默认为0
        :type Volume: float
        :param Speed: 语速，范围：[-2，2]，分别对应不同语速：0.6倍，0.8倍，1.0倍，1.2倍，1.5倍，默认为0
        :type Speed: float
        :param ProjectId: 项目id，用户自定义，默认为0
        :type ProjectId: int
        :param VoiceType: 音色<li>0-女声1，亲和风格(默认)</li><li>1-男声1，成熟风格</li><li>2-男声2，成熟风格</li>
        :type VoiceType: int
        :param PrimaryLanguage: 主语言类型<li>1-中文(包括粤语)，最大100字符</li><li>2-英文，最大支持400字符</li>
        :type PrimaryLanguage: int
        :param SampleRate: 音频采样率，16000：16k，8000：8k，默认16k
        :type SampleRate: int
        """
        self.Text = None
        self.SessionId = None
        self.ModelType = None
        self.Volume = None
        self.Speed = None
        self.ProjectId = None
        self.VoiceType = None
        self.PrimaryLanguage = None
        self.SampleRate = None


    def _deserialize(self, params):
        self.Text = params.get("Text")
        self.SessionId = params.get("SessionId")
        self.ModelType = params.get("ModelType")
        self.Volume = params.get("Volume")
        self.Speed = params.get("Speed")
        self.ProjectId = params.get("ProjectId")
        self.VoiceType = params.get("VoiceType")
        self.PrimaryLanguage = params.get("PrimaryLanguage")
        self.SampleRate = params.get("SampleRate")


class TextToVoiceResponse(AbstractModel):
    """TextToVoice返回参数结构体

    """

    def __init__(self):
        """
        :param Audio: base编码的wav音频
        :type Audio: str
        :param SessionId: 一次请求对应一个SessionId
        :type SessionId: str
        :param RequestId: 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
        :type RequestId: str
        """
        self.Audio = None
        self.SessionId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Audio = params.get("Audio")
        self.SessionId = params.get("SessionId")
        self.RequestId = params.get("RequestId")

==> tencentcloud_sdk_python-3.0.53-py2.py3-none-any.whl: tencentcloud/aai/v20180522/models.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from tencentcloud.common.abstract_model import AbstractModel


class ChatRequest(AbstractModel):
    """Chat请求参数结构体

    """

    def __init__(self):
        """
        :param Text: 聊天输入文本
        :type Text: str
        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
        :type ProjectId: int
        :param User: json格式，比如 {"id":"test","gender":"male"}。记录当前与机器人交互的用户id，非必须但强烈建议传入，否则多轮聊天功能会受影响
        :type User: str
        """
        self.Text = None
        self.ProjectId = None
        self.User = None


    def _deserialize(self, params):
        self.Text = params.get("Text")
        self.ProjectId = params.get("ProjectId")
        self.User = params.get("User")


class ChatResponse(AbstractModel):
    """Chat返回参数结构体

    """

    def __init__(self):
        """
        :param Answer: 聊天输出文本
        :type Answer: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Answer = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Answer = params.get("Answer")
        self.RequestId = params.get("RequestId")


class SentenceRecognitionRequest(AbstractModel):
    """SentenceRecognition请求参数结构体

    """

    def __init__(self):
        """
        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
        :type ProjectId: int
        :param SubServiceType: 子服务类型。2，一句话识别。
        :type SubServiceType: int
        :param EngSerViceType: 引擎类型。8k：电话 8k 通用模型；16k：16k 通用模型。只支持单声道音频识别。
        :type EngSerViceType: str
        :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
        :type SourceType: int
        :param VoiceFormat: 识别音频的音频格式（支持mp3,wav）。
        :type VoiceFormat: str
        :param UsrAudioKey: 用户端对此任务的唯一标识，用户自助生成，用于用户查找识别结果。
        :type UsrAudioKey: str
        :param Url: 语音 URL，公网可下载。当 SourceType 值为 0 时须填写该字段，为 1 时不填；URL 的长度大于 0，小于 2048，需进行urlencode编码。音频时间长度要小于60s。
        :type Url: str
        :param Data: 语音数据，当SourceType 值为1时必须填写，为0可不写。要base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。音频数据要小于900k。
        :type Data: str
        :param DataLen: 数据长度，当 SourceType 值为1时必须填写，为0可不写（此数据长度为数据未进行base64编码时的数据长度）。
        :type DataLen: int
        """
        self.ProjectId = None
        self.SubServiceType = None
        self.EngSerViceType = None
        self.SourceType = None
        self.VoiceFormat = None
        self.UsrAudioKey = None
        self.Url = None
        self.Data = None
        self.DataLen = None


    def _deserialize(self, params):
        self.ProjectId = params.get("ProjectId")
        self.SubServiceType = params.get("SubServiceType")
        self.EngSerViceType = params.get("EngSerViceType")
        self.SourceType = params.get("SourceType")
        self.VoiceFormat = params.get("VoiceFormat")
        self.UsrAudioKey = params.get("UsrAudioKey")
        self.Url = params.get("Url")
        self.Data = params.get("Data")
        self.DataLen = params.get("DataLen")


class SentenceRecognitionResponse(AbstractModel):
    """SentenceRecognition返回参数结构体

    """

    def __init__(self):
        """
        :param Result: 识别结果。
        :type Result: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Result = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Result = params.get("Result")
        self.RequestId = params.get("RequestId")


class SimultaneousInterpretingRequest(AbstractModel):
    """SimultaneousInterpreting请求参数结构体

    """

    def __init__(self):
        """
        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
        :type ProjectId: int
        :param SubServiceType: 子服务类型。0：离线语音识别。1：实时流式识别，2，一句话识别。3：同传。
        :type SubServiceType: int
        :param RecEngineModelType: 识别引擎类型。8k_zh： 8k 中文会场模型；16k_zh：16k 中文会场模型，8k_en： 8k 英文会场模型；16k_en：16k 英文会场模型。当前仅支持16K。
        :type RecEngineModelType: str
        :param Data: 语音数据，要base64编码。
        :type Data: str
        :param DataLen: 数据长度。
        :type DataLen: int
        :param VoiceId: 声音id，标识一句话。
        :type VoiceId: str
        :param IsEnd: 是否是一句话的结束。
        :type IsEnd: int
        :param VoiceFormat: 声音编码的格式1:pcm，4:speex，6:silk，默认为1。
        :type VoiceFormat: int
        :param OpenTranslate: 是否需要翻译结果，1表示需要翻译，0是不需要。
        :type OpenTranslate: int
        :param SourceLanguage: 如果需要翻译，表示源语言类型，可取值：zh，en。
        :type SourceLanguage: str
        :param TargetLanguage: 如果需要翻译，表示目标语言类型，可取值：zh，en。
        :type TargetLanguage: str
        :param Seq: 表明当前语音分片的索引，从0开始
        :type Seq: int
        """
        self.ProjectId = None
        self.SubServiceType = None
        self.RecEngineModelType = None
        self.Data = None
        self.DataLen = None
        self.VoiceId = None
        self.IsEnd = None
        self.VoiceFormat = None
        self.OpenTranslate = None
        self.SourceLanguage = None
        self.TargetLanguage = None
        self.Seq = None


    def _deserialize(self, params):
        self.ProjectId = params.get("ProjectId")
        self.SubServiceType = params.get("SubServiceType")
        self.RecEngineModelType = params.get("RecEngineModelType")
        self.Data = params.get("Data")
        self.DataLen = params.get("DataLen")
        self.VoiceId = params.get("VoiceId")
        self.IsEnd = params.get("IsEnd")
        self.VoiceFormat = params.get("VoiceFormat")
        self.OpenTranslate = params.get("OpenTranslate")
        self.SourceLanguage = params.get("SourceLanguage")
        self.TargetLanguage = params.get("TargetLanguage")
        self.Seq = params.get("Seq")


class SimultaneousInterpretingResponse(AbstractModel):
    """SimultaneousInterpreting返回参数结构体

    """

    def __init__(self):
        """
        :param AsrText: 语音识别的结果
        :type AsrText: str
        :param NmtText: 机器翻译的结果
        :type NmtText: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.AsrText = None
        self.NmtText = None
        self.RequestId = None


    def _deserialize(self, params):
        self.AsrText = params.get("AsrText")
        self.NmtText = params.get("NmtText")
        self.RequestId = params.get("RequestId")


class TextToVoiceRequest(AbstractModel):
    """TextToVoice请求参数结构体

    """

    def __init__(self):
        """
        :param Text: 合成语音的源文本
        :type Text: str
        :param SessionId: 一次请求对应一个SessionId，会原样返回，建议传入类似于uuid的字符串防止重复
        :type SessionId: str
        :param ModelType: 模型类型，1-默认模型
        :type ModelType: int
        :param Volume: 音量大小，范围：[0，10]，分别对应10个等级的音量，默认为0
        :type Volume: float
        :param Speed: 语速，范围：[-2，2]，分别对应不同语速：0.6倍，0.8倍，1.0倍，1.2倍，1.5倍，默认为0
        :type Speed: float
        :param ProjectId: 项目id，用户自定义，默认为0
        :type ProjectId: int
        :param VoiceType: 音色<li>0-女声1，亲和风格(默认)</li><li>1-男声1，成熟风格</li><li>2-男声2，成熟风格</li>
        :type VoiceType: int
        :param PrimaryLanguage: 主语言类型<li>1-中文，最大100个汉字（标点符号算一个汉子）</li><li>2-英文，最大支持400个字母（标点符号算一个字母）</li>
        :type PrimaryLanguage: int
        :param SampleRate: 音频采样率，16000：16k，8000：8k，默认16k
        :type SampleRate: int
        """
        self.Text = None
        self.SessionId = None
        self.ModelType = None
        self.Volume = None
        self.Speed = None
        self.ProjectId = None
        self.VoiceType = None
        self.PrimaryLanguage = None
        self.SampleRate = None


    def _deserialize(self, params):
        self.Text = params.get("Text")
        self.SessionId = params.get("SessionId")
        self.ModelType = params.get("ModelType")
        self.Volume = params.get("Volume")
        self.Speed = params.get("Speed")
        self.ProjectId = params.get("ProjectId")
        self.VoiceType = params.get("VoiceType")
        self.PrimaryLanguage = params.get("PrimaryLanguage")
        self.SampleRate = params.get("SampleRate")


class TextToVoiceResponse(AbstractModel):
    """TextToVoice返回参数结构体

    """

    def __init__(self):
        """
        :param Audio: base编码的wav音频
        :type Audio: str
        :param SessionId: 一次请求对应一个SessionId
        :type SessionId: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Audio = None
        self.SessionId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Audio = params.get("Audio")
        self.SessionId = params.get("SessionId")
        self.RequestId = params.get("RequestId")
